==> haskell-cracknum-2.4-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cracknum.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 crackNum
version:              2.4
visibility:           public
id:                   crackNum-2.4-7t5pt5XgbTp1wD2iRRUx4g
key:                  crackNum-2.4-7t5pt5XgbTp1wD2iRRUx4g
license:              BSD-3-Clause
copyright:            Levent Erkok
maintainer:           erkokl@gmail.com
author:               Levent Erkok
homepage:             http://github.com/LeventErkok/CrackNum
synopsis:             Crack various integer, floating-point data formats
description:
    Crack HP, SP and DP floats and 8, 16, 32, 64 bit words and integers.

    For details, please see: <http://github.com/LeventErkok/crackNum/>

category:             Tools
abi:                  004fa9a336eba7149291b8f2bf652a7d
exposed:              True
exposed-modules:      Data.Numbers.CrackNum
hidden-modules:
    Data.Numbers.CrackNum.Utils Data.Numbers.CrackNum.Data

import-dirs:          /usr/lib/ghc-8.10.5/site-local/crackNum-2.4
library-dirs:         /usr/lib/ghc-8.10.5/site-local/crackNum-2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.5/crackNum-2.4
hs-libraries:         HScrackNum-2.4-7t5pt5XgbTp1wD2iRRUx4g
depends:
    FloatingHex-0.5-2TdMqcCNIQJKe2hQGvpHYV array-0.5.4.0 base-4.14.2.0

haddock-interfaces:   /usr/share/doc/haskell-cracknum/html/crackNum.haddock
haddock-html:         /usr/share/doc/haskell-cracknum/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cracknum-2.4-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cracknum.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 crackNum
version:              2.4
visibility:           public
id:                   crackNum-2.4-JGYL9ec6dE7G0zR1GtqCs4
key:                  crackNum-2.4-JGYL9ec6dE7G0zR1GtqCs4
license:              BSD-3-Clause
copyright:            Levent Erkok
maintainer:           erkokl@gmail.com
author:               Levent Erkok
homepage:             http://github.com/LeventErkok/CrackNum
synopsis:             Crack various integer, floating-point data formats
description:
    Crack HP, SP and DP floats and 8, 16, 32, 64 bit words and integers.

    For details, please see: <http://github.com/LeventErkok/crackNum/>

category:             Tools
abi:                  95e951fa460015f867c2d008a8adb247
exposed:              True
exposed-modules:      Data.Numbers.CrackNum
hidden-modules:
    Data.Numbers.CrackNum.Utils Data.Numbers.CrackNum.Data

import-dirs:          /usr/lib/ghc-9.0.1/site-local/crackNum-2.4
library-dirs:         /usr/lib/ghc-9.0.1/site-local/crackNum-2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/crackNum-2.4
hs-libraries:         HScrackNum-2.4-JGYL9ec6dE7G0zR1GtqCs4
depends:
    FloatingHex-0.5-7pijLrWv68I61QKVSLlVAY array-0.5.4.0 base-4.15.0.0

haddock-interfaces:   /usr/share/doc/haskell-cracknum/html/crackNum.haddock
haddock-html:         /usr/share/doc/haskell-cracknum/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
